@@ -1,14 +1,15 @@
 package File::Truncate::Undoable;
 
+our $DATE = '2015-08-17'; # DATE
+our $VERSION = '0.03'; # VERSION
+
 use 5.010001;
 use strict;
 use warnings;
-use Log::Any '$log';
+use Log::Any::IfLOG '$log';
 
 use File::Trash::Undoable;
 
-our $VERSION = '0.02'; # VERSION
-
 our %SPEC;
 
 $SPEC{truncate} = {
@@ -102,15 +103,20 @@ File::Truncate::Undoable - Truncate a file, with undo support
 
 =head1 VERSION
 
-This document describes version 0.02 of File::Truncate::Undoable (from Perl distribution File-Truncate-Undoable), released on 2014-05-17.
+This document describes version 0.03 of File::Truncate::Undoable (from Perl distribution File-Truncate-Undoable), released on 2015-08-17.
+
+=head1 SEE ALSO
+
+L<Rinci::Transaction>
 
 =head1 FUNCTIONS
 
 
 =head2 truncate(%args) -> [status, msg, result, meta]
 
-Truncate a file, with undo support.
+{en_US Truncate a file, with undo support}.
 
+{en_US 
 On do, will trash file then create an empty file (with the same permission and
 ownership as the original). On undo, will trash the new file and untrash the old
 file.
@@ -124,6 +130,7 @@ Fixable state: file exists and size is not zero.
 
 Unfixable state: file does not exist or path is not a regular file (directory
 and symlink included).
+}
 
 This function is idempotent (repeated invocations with same arguments has the same effect as single invocation). This function supports transactions.
 
@@ -162,8 +169,6 @@ For more information on transaction, see L<Rinci::Transaction>.
 
 =back
 
-Return value:
-
 Returns an enveloped result (an array).
 
 First element (status) is an integer containing HTTP status code
@@ -173,9 +178,7 @@ First element (status) is an integer containing HTTP status code
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
-=head1 SEE ALSO
-
-L<Rinci::Transaction>
+Return value:  (any)
 
 =head1 HOMEPAGE
 
@@ -195,11 +198,11 @@ feature.
 
 =head1 AUTHOR
 
-Steven Haryanto <stevenharyanto@gmail.com>
+perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Steven Haryanto.
+This software is copyright (c) 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
